Установка библиотеки
====================

Установка библиотеки производится из репозитория `PYPI <https://pypi.org/project/yandex-360/>`_ командой:

.. code-block:: console

    $ pip install yandex_360

Подключение библиотеки
======================

Библиотека является пакетом ``yandex_360`` с модулями функций ``users``, ``departments``, ``groups``, ``mail``, ``domains``, ``dns``, ``pwd``, ``auth``, ``logs``, ``2fa``, ``org``, ``tools``, ``antispam`` и ``routing``

.. code-block:: python

    from yandex_360 import users, departments, groups, mail, domains, dns, pwd, auth, logs, 2fa, org,  tools, antispam, routing
